<meta charset="utf-8">
<meta http-equiv="X-UA-Compatible" content="IE=edge">
<meta name="viewport" content="width=device-width, initial-scale=1">
<link href="{{ url_for('feed',name='recent') }}"
      rel="alternate"
      title="Recent posts"
      type="application/atom+xml">
{% if page is defined %}
    {% if page.descripton is defined %}
        <meta name="description" content="{{ page.description }}">
    {% else %}
        {% if page.summary is defined %}
            <meta name="description" content="{{ page.summary }}">
        {% endif %}
    {% endif %}
    {% if page.tags is defined %}
        <meta name="keywords" content="{{ page.tags }}">
    {% endif %}

    {% if page.ref_to is defined %}
        <meta http-equiv="refresh" content="{{ page.wait if page.wait is defined else 0 }};url={{ page.ref_to }}">
    {% endif %}
{% endif %}